@@ -3,7 +3,7 @@ package Data::CSel;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-07-01'; # DATE
 our $DIST = 'Data-CSel'; # DIST
-our $VERSION = '0.124'; # VERSION
+our $VERSION = '0.125'; # VERSION
 
 use 5.020000;
 use strict;
@@ -619,6 +619,12 @@ sub _simpsel {
                 @res = grep { Code::Includable::Tree::NodeMethods::is_nth_last_child_of_type($_, $f->{args}[0]) } @res;
             } elsif ($pc eq 'root') {
                 @res = grep { Code::Includable::Tree::NodeMethods::is_root($_) } @res;
+            } elsif ($pc eq 'has-min-children') {
+                @res = grep { Code::Includable::Tree::NodeMethods::has_min_children($_, $f->{args}[0]) } @res;
+            } elsif ($pc eq 'has-max-children') {
+                @res = grep { Code::Includable::Tree::NodeMethods::has_max_children($_, $f->{args}[0]) } @res;
+            } elsif ($pc eq 'has-children-between') {
+                @res = grep { Code::Includable::Tree::NodeMethods::has_children_between($_, $f->{args}[0], $f->{args}[1]) } @res;
             } elsif ($pc eq 'empty') {
                 @res = grep { my @c = Code::Includable::Tree::NodeMethods::_children_as_list($_); !@c } @res;
             } elsif ($pc eq 'has') {
@@ -736,7 +742,7 @@ Data::CSel - Select tree node objects using CSS Selector-like syntax
 
 =head1 VERSION
 
-This document describes version 0.124 of Data::CSel (from Perl distribution Data-CSel), released on 2021-07-01.
+This document describes version 0.125 of Data::CSel (from Perl distribution Data-CSel), released on 2021-07-01.
 
 =head1 SYNOPSIS
 
@@ -1255,6 +1261,18 @@ type.
 
 Select only root node(s).
 
+=item * C<:has-min-children(m)>
+
+Select only objects that have at least I<m> direct children.
+
+=item * C<:has-max-children(n)>
+
+Select only objects that have at most I<n> direct children.
+
+=item * C<:has-children-between(m,n)>
+
+Select only objects that have between I<m> and I<n> direct children.
+
 =item * C<:parent>
 
 Select the node's parent.
@@ -1315,6 +1333,8 @@ C<[attr =~ /re/]>.
 Some CSS pseudo-classes only make sense for a DOM or a visual browser, e.g.
 C<:link>, C<:visited>, C<:hover>, so they are not supported.
 
+CSS selector does not sport C<:parent>.
+
 =head3 There is no concept of CSS namespaces
 
 CSS namespaces are used when there are foreign elements (e.g. SVG in addition to
